@@ -108,7 +108,7 @@ def to_str(data):
 @register.simple_tag
 def sentry_version():
     import sentry
-    return sentry.VERSION
+    return sentry.get_version()
 
 
 @register.filter
@@ -364,4 +364,12 @@ def get_rendered_interfaces(event):
         if not html:
             continue
         interface_list.append((interface, mark_safe(html)))
-    return interface_list
+    return sorted(interface_list, key=lambda x: x[0].get_display_score(), reverse=True)
+
+
+@register.inclusion_tag('sentry/partial/github_button.html')
+def github_button(user, repo):
+    return {
+        'user': user,
+        'repo': repo,
+    }
